# Journal Scraper

Scraping journal websites for papers using selenium. Installs a command `biolit`.
Use `biolit --help`.


for python>=3.12
probably requires `pip install setuptools` for `undetected-chromedriver` to be imported
use `pip install journal-scraper[selenium]`
